@@ -3,6 +3,11 @@
 
 #include "account/preferences.h"
 
+#include <QJsonDocument>
+#include <QNetworkReply>
+#include <QNetworkRequest>
+#include <qhttpmultipart.h>
+
 #include "account/abstractaccount.h"
 
 Preferences::Preferences(AbstractAccount *account)
@@ -107,4 +112,4 @@ void Preferences::setPreferencesField(const QString &name, const QString &value)
     m_account->patch(m_account->apiUrl(QStringLiteral("/api/v1/accounts/update_credentials")), multiPart, true, this, [](QNetworkReply *) {});
 }
 
-#include "moc_preferences.cpp"
\ No newline at end of file
+#include "moc_preferences.cpp"
