@@ -7,7 +7,12 @@
 #include "utils/texthandler.h"
 
 #include <KLocalizedString>
+#include <QJsonDocument>
+#include <QNetworkReply>
 #include <QTextDocument>
+#include <qfileinfo.h>
+#include <qhttpmultipart.h>
+#include <qmimedatabase.h>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -244,6 +249,8 @@ void ProfileEditorBackend::fetchAccountInfo()
             m_fields.append(field);
         }
         Q_EMIT fieldsChanged();
+
+        m_account->identity()->fromSourceData(obj);
     });
 }
 
@@ -278,7 +285,7 @@ void ProfileEditorBackend::save()
     discoverablePart.setBody(discoverable() ? "1" : "0");
     multiPart->append(discoverablePart);
 
-    for (int i = 0; i < m_fields.size(); i++) {
+    for (int i = 0; i < maxFields(); i++) {
         QHttpPart fieldNamePart;
         fieldNamePart.setHeader(QNetworkRequest::ContentDispositionHeader, QStringLiteral("form-data; name=\"fields_attributes[%1][name]\"").arg(i));
         fieldNamePart.setBody(m_fields[i]["name"_L1].toString().toUtf8());
@@ -326,11 +333,29 @@ void ProfileEditorBackend::save()
         multiPart->append(headerPart);
     }
 
-    m_account->patch(url, multiPart, true, this, [=](QNetworkReply *reply) {
+    m_account->patch(url, multiPart, true, this, [this, multiPart](QNetworkReply *reply) {
         multiPart->setParent(reply);
         Q_EMIT sendNotification(i18n("Account details saved"));
         fetchAccountInfo();
     });
 }
 
-#include "moc_profileeditor.cpp"
\ No newline at end of file
+int ProfileEditorBackend::maxFields() const
+{
+    // TODO: some instances support more fields
+    return 4;
+}
+
+void ProfileEditorBackend::addField()
+{
+    m_fields.push_back({});
+    Q_EMIT fieldsChanged();
+}
+
+void ProfileEditorBackend::removeField()
+{
+    m_fields.pop_back();
+    Q_EMIT fieldsChanged();
+}
+
+#include "moc_profileeditor.cpp"
