@@ -3,7 +3,8 @@
 
 #pragma once
 
-#include <QtQml>
+#include <QJsonArray>
+#include <QQmlEngine>
 
 class AbstractAccount;
 
@@ -27,6 +28,7 @@ class ProfileEditorBackend : public QObject
     Q_PROPERTY(bool locked READ locked WRITE setLocked NOTIFY lockedChanged)
     Q_PROPERTY(bool discoverable READ discoverable WRITE setDiscoverable NOTIFY discoverableChanged)
     Q_PROPERTY(QJsonArray fields READ fields WRITE setFields NOTIFY fieldsChanged)
+    Q_PROPERTY(int maxFields READ maxFields CONSTANT)
 
 public:
     explicit ProfileEditorBackend(QObject *parent = nullptr);
@@ -145,11 +147,25 @@ public:
      */
     void setLocked(bool locked);
 
+    /**
+     * @return The maximum number of supported profile fields.
+     */
+    int maxFields() const;
+
 public Q_SLOTS:
     void save();
     void fetchAccountInfo();
     void setFieldName(int index, const QString &name);
     void setFieldValue(int index, const QString &value);
+    /**
+     * @brief Adds a profile field.
+     */
+    void addField();
+
+    /**
+     * @brief Removes a profile field.
+     */
+    void removeField();
 
 Q_SIGNALS:
     void accountChanged();
