@@ -3,7 +3,8 @@
 
 #pragma once
 
-#include <QtQml>
+#include <QAbstractListModel>
+#include <QQmlEngine>
 
 class Identity;
 
@@ -76,6 +77,7 @@ Q_SIGNALS:
     void accountIdChanged();
     void statusIdChanged();
     void listIdChanged();
+    void networkErrorOccurred(const QString &message);
 
 protected:
     void fetchMore(const QModelIndex &parent) override;
@@ -94,4 +96,4 @@ private:
     QString m_statusId;
     QString m_listId;
     int m_count = 0;
-};
\ No newline at end of file
+};
