@@ -4,10 +4,14 @@
 #pragma once
 
 #include <QDateTime>
+#include <QQmlEngine>
 
 class IpInfo
 {
     Q_GADGET
+    QML_ELEMENT
+    QML_NAMED_ELEMENT(ipInfo)
+    QML_UNCREATABLE("Only for enums")
 
 public:
     enum SeverityValues { LimitSignUps, BlockSignUps, BlockAccess };
