@@ -1,8 +1,11 @@
 // SPDX-FileCopyrightText: 2021 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
+#include <QCommandLineParser>
+#include <QQmlApplicationEngine>
 #include <QQuickStyle>
 #include <QQuickWindow>
+#include <QUrlQuery>
 
 #ifdef HAVE_WEBVIEW
 #include <QtWebView>
@@ -19,18 +22,21 @@
 #include <KDBusService>
 #include <KWindowSystem>
 #endif
+#include <KIconTheme>
+#include <KLocalizedQmlContext>
 #include <KLocalizedString>
 
 #ifdef HAVE_KUNIFIEDPUSH
 #include <kunifiedpush/connector.h>
 #endif
 
+#include <QNetworkProxyFactory>
+
 #include "tokodon-version.h"
 
 #include "account/accountmanager.h"
 #include "accountconfig.h"
 #include "admin/emailinfo.h"
-#include "admin/ipinfo.h"
 #include "config.h"
 #include "network/networkaccessmanagerfactory.h"
 #include "network/networkcontroller.h"
@@ -72,6 +78,7 @@ Q_DECL_EXPORT
 #endif
 int main(int argc, char *argv[])
 {
+    KIconTheme::initTheme();
     QNetworkProxyFactory::setUseSystemConfiguration(true);
 
 #ifdef HAVE_WEBVIEW
@@ -114,7 +121,7 @@ int main(int argc, char *argv[])
                      QStringLiteral(TOKODON_VERSION_STRING),
                      i18n("Browse the Fediverse"),
                      KAboutLicense::GPL_V3,
-                     i18n("© 2021-2024 Carl Schwan, 2021-2024 KDE Community"));
+                     i18n("© 2021-2024 KDE Community"));
     about.addAuthor(i18n("Carl Schwan"),
                     i18n("Maintainer"),
                     QStringLiteral("carl@carlschwan.eu"),
@@ -138,7 +145,7 @@ int main(int argc, char *argv[])
 
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("Browse the Fediverse"));
-    parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports https and web+ap url scheme"));
+    parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports https, tokodon and web+ap url scheme"));
 
     QCommandLineOption shareOption(QStringLiteral("share"), i18n("Share a line of text in the standalone composer."), i18n("The text to share."));
     shareOption.setFlags(QCommandLineOption::Flag::HiddenFromHelp);
@@ -153,17 +160,10 @@ int main(int argc, char *argv[])
     about.processCommandLine(&parser);
 
     auto &colorSchemer = ColorSchemer::instance();
-    auto config = Config::self();
-    if (!config->colorScheme().isEmpty()) {
-        colorSchemer.apply(config->colorScheme());
+    if (!Config::colorScheme().isEmpty()) {
+        colorSchemer.apply(Config::colorScheme());
     }
 
-    qmlRegisterSingletonInstance("org.kde.tokodon.private", 1, 0, "Config", config);
-    qmlRegisterUncreatableType<AccountConfig>("org.kde.tokodon.private", 1, 0, "AccountConfig", QStringLiteral("Use via Account.config"));
-    qmlRegisterUncreatableMetaObject(Notification::staticMetaObject, "org.kde.tokodon", 1, 0, "Notification", QStringLiteral("Only for enums"));
-    qmlRegisterUncreatableMetaObject(IpInfo::staticMetaObject, "org.kde.tokodon", 1, 0, "IpInfo", QStringLiteral("Only for enums"));
-    qmlRegisterUncreatableMetaObject(EmailInfo::staticMetaObject, "org.kde.tokodon", 1, 0, "EmailInfo", QStringLiteral("Only for enums"));
-
     QQmlApplicationEngine engine;
 
 #ifdef HAVE_KUNIFIEDPUSH
@@ -215,14 +215,14 @@ int main(int argc, char *argv[])
                 args.removeFirst();
 
                 if (!args.empty()) {
-                    if (args.first().startsWith("web+ap"_L1)) {
-                        NetworkController::instance().openWebApLink(args[0]);
-                    } else if (args.first().startsWith("tokodon"_L1)) {
-                        NetworkController::instance().setAuthCode(QUrl(args[0]));
+                    if (args.first().startsWith("tokodon"_L1)) {
+                        if (!NetworkController::instance().setAuthCode(QUrl(args.first()))) {
+                            NetworkController::instance().openWebApLink(args.first());
+                        }
                     } else if (args.first() == "--share"_L1) {
                         NetworkController::instance().startComposing(args[1]);
                     } else {
-                        NetworkController::instance().openWebApLink(args[0]);
+                        NetworkController::instance().openWebApLink(args.first());
                     }
                 }
 
@@ -231,8 +231,7 @@ int main(int argc, char *argv[])
         }
     });
 #endif
-    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    QObject::connect(&engine, &QQmlApplicationEngine::quit, &app, &QCoreApplication::quit);
+    KLocalization::setupLocalizedContext(&engine);
 
     NetworkAccessManagerFactory namFactory;
     engine.setNetworkAccessManagerFactory(&namFactory);
@@ -273,7 +272,7 @@ int main(int argc, char *argv[])
     } else {
         engine.loadFromModule("org.kde.tokodon", "Main");
 
-        if (parser.positionalArguments().length() > 0) {
+        if (!parser.positionalArguments().empty()) {
             NetworkController::instance().openWebApLink(parser.positionalArguments()[0]);
         }
     }
