@@ -4,9 +4,13 @@
 #include "notification/notificationmodel.h"
 
 #include "account/abstractaccount.h"
+#include "networkcontroller.h"
 #include "texthandler.h"
 
 #include <KLocalizedString>
+#include <QJsonDocument>
+#include <QNetworkReply>
+#include <QUrlQuery>
 
 NotificationModel::NotificationModel(QObject *parent)
     : AbstractTimelineModel(parent)
@@ -14,7 +18,7 @@ NotificationModel::NotificationModel(QObject *parent)
     m_manager = &AccountManager::instance();
     m_account = m_manager->selectedAccount();
 
-    connect(m_manager, &AccountManager::accountSelected, this, [=](AbstractAccount *account) {
+    connect(m_manager, &AccountManager::accountSelected, this, [this](AbstractAccount *account) {
         if (m_account != account) {
             m_account = account;
 
@@ -82,38 +86,46 @@ void NotificationModel::fillTimeline(const QUrl &next)
     }
     uri.setQuery(urlQuery);
 
-    m_account->get(uri, true, this, [=](QNetworkReply *reply) {
-        const auto data = reply->readAll();
-        const auto doc = QJsonDocument::fromJson(data);
+    m_account->get(
+        uri,
+        true,
+        this,
+        [this](QNetworkReply *reply) {
+            const auto data = reply->readAll();
+            const auto doc = QJsonDocument::fromJson(data);
 
-        if (!doc.isArray()) {
-            m_account->errorOccured(i18n("Error occurred when fetching the latest notification."));
-            return;
-        }
+            if (!doc.isArray()) {
+                m_account->errorOccured(i18n("Error occurred when fetching the latest notification."));
+                return;
+            }
 
-        const auto linkHeader = QString::fromUtf8(reply->rawHeader(QByteArrayLiteral("Link")));
-        m_next = TextHandler::getNextLink(linkHeader);
+            const auto linkHeader = QString::fromUtf8(reply->rawHeader(QByteArrayLiteral("Link")));
+            m_next = TextHandler::getNextLink(linkHeader);
 
-        QList<std::shared_ptr<Notification>> notifications;
-        const auto values = doc.array();
-        for (const auto &value : values) {
-            const QJsonObject obj = value.toObject();
-            const auto notification = std::make_shared<Notification>(m_account, obj, this);
+            QList<std::shared_ptr<Notification>> notifications;
+            const auto values = doc.array();
+            for (const auto &value : values) {
+                const QJsonObject obj = value.toObject();
+                const auto notification = std::make_shared<Notification>(m_account, obj, this);
 
-            notifications.push_back(notification);
-        }
+                notifications.push_back(notification);
+            }
+
+            if (notifications.isEmpty()) {
+                setLoading(false);
+                return;
+            }
+
+            beginInsertRows({}, m_notifications.count(), m_notifications.count() + notifications.count() - 1);
+            m_notifications.append(notifications);
+            endInsertRows();
 
-        if (notifications.isEmpty()) {
             setLoading(false);
-            return;
-        }
-
-        beginInsertRows({}, m_notifications.count(), m_notifications.count() + notifications.count() - 1);
-        m_notifications.append(notifications);
-        endInsertRows();
-
-        setLoading(false);
-    });
+        },
+        [this](QNetworkReply *reply) {
+            setLoading(false);
+            Q_EMIT NetworkController::instance().networkErrorOccurred(reply->errorString());
+        });
 }
 
 void NotificationModel::fetchMore(const QModelIndex &parent)
@@ -181,6 +193,8 @@ QVariant NotificationModel::data(const QModelIndex &index, int role) const
         return QVariant::fromValue<ReportInfo *>(notification->report());
     case RelationshipSeveranceEventRole:
         return QVariant::fromValue<RelationshipSeveranceEvent>(*notification->relationshipSeveranceEvent());
+    case AnnualReportEventRole:
+        return QVariant::fromValue<AnnualReportEvent>(*notification->annualReportEvent());
     case ModerationWarningRole:
         return QVariant::fromValue<AccountWarning>(*notification->accountWarning());
     default:
@@ -197,6 +211,7 @@ QHash<int, QByteArray> NotificationModel::roleNames() const
     roles.insert(ReportRole, QByteArrayLiteral("report"));
     roles.insert(RelationshipSeveranceEventRole, QByteArrayLiteral("relationshipSeveranceEvent"));
     roles.insert(ModerationWarningRole, QByteArrayLiteral("moderationWarning"));
+    roles.insert(AnnualReportEventRole, QByteArrayLiteral("annualReportEvent"));
     return roles;
 }
 
@@ -265,4 +280,13 @@ void NotificationModel::actionDelete(const QModelIndex &index)
     }
 }
 
-#include "moc_notificationmodel.cpp"
\ No newline at end of file
+void NotificationModel::actionMute(const QModelIndex &index)
+{
+    const int row = index.row();
+    const auto post = m_notifications[row]->post();
+    if (post != nullptr) {
+        AbstractTimelineModel::actionMute(index, post);
+    }
+}
+
+#include "moc_notificationmodel.cpp"
