@@ -4,8 +4,14 @@
 #include "timeline/accountmodel.h"
 
 #include "account/relationship.h"
+#include "networkcontroller.h"
 
 #include <KLocalizedString>
+#include <QJsonDocument>
+#include <QNetworkReply>
+#include <QUrlQuery>
+
+#include "tokodon_debug.h"
 
 AccountModel::AccountModel(QObject *parent)
     : TimelineModel(parent)
@@ -82,8 +88,8 @@ void AccountModel::fillTimeline(const QString &fromId, bool backwards)
     const auto id = m_accountId;
 
     auto handleError = [this](QNetworkReply *reply) {
-        Q_UNUSED(reply);
         setLoading(false);
+        NetworkController::instance().networkErrorOccurred(reply->errorString());
     };
 
     auto onFetchPinned = [this, id, account](QNetworkReply *reply) {
@@ -104,12 +110,12 @@ void AccountModel::fillTimeline(const QString &fromId, bool backwards)
         }
 
         QList<Post *> posts;
-        std::transform(array.cbegin(), array.cend(), std::back_inserter(posts), [this](const QJsonValue &value) {
+        std::ranges::transform(std::as_const(array), std::back_inserter(posts), [this](const QJsonValue &value) {
             auto post = new Post(m_account, value.toObject(), this);
             post->setPinned(true);
             return post;
         });
-        std::reverse(posts.begin(), posts.end());
+        std::ranges::reverse(posts);
         beginInsertRows({}, 0, posts.size() - 1);
         m_timeline = posts + m_timeline;
         endInsertRows();
@@ -171,7 +177,6 @@ void AccountModel::setAccountId(const QString &accountId)
         Q_EMIT identityChanged();
         updateRelationships();
     }
-    Q_EMIT accountIdChanged();
 
     reset();
     fillTimeline();
@@ -197,8 +202,8 @@ void AccountModel::updateRelationships()
     m_account->get(uriRelationship, true, this, [this](QNetworkReply *reply) {
         const auto doc = QJsonDocument::fromJson(reply->readAll());
         if (!doc.isArray()) {
-            qWarning() << "Data returned from Relationship network request is not an array"
-                       << "data: " << doc;
+            qWarning(TOKODON_LOG) << "Data returned from Relationship network request is not an array"
+                                  << "data: " << doc;
             return;
         }
 
@@ -237,4 +242,4 @@ void AccountModel::reset()
     endResetModel();
 }
 
-#include "moc_accountmodel.cpp"
\ No newline at end of file
+#include "moc_accountmodel.cpp"
