@@ -3,6 +3,8 @@
 
 #include "timeline/notification.h"
 
+#include "tokodon_debug.h"
+
 using namespace Qt::StringLiterals;
 
 Post *Notification::createPost(AbstractAccount *account, const QJsonObject &obj, QObject *parent)
@@ -89,9 +91,14 @@ QString RelationshipSeveranceEvent::targetName() const
     return m_targetName;
 }
 
-int RelationshipSeveranceEvent::relationshipsCount() const
+int RelationshipSeveranceEvent::followersCount() const
 {
-    return m_followersCount + m_followingCount;
+    return m_followersCount;
+}
+
+int RelationshipSeveranceEvent::followingCount() const
+{
+    return m_followingCount;
 }
 
 QDateTime RelationshipSeveranceEvent::createdAt() const
@@ -99,6 +106,18 @@ QDateTime RelationshipSeveranceEvent::createdAt() const
     return m_createdAt;
 }
 
+AnnualReportEvent::AnnualReportEvent() = default;
+
+AnnualReportEvent::AnnualReportEvent(const QJsonObject &source)
+    : m_year(source["year"_L1].toString())
+{
+}
+
+QString AnnualReportEvent::year() const
+{
+    return m_year;
+}
+
 static QMap<QString, Notification::Type> str_to_not_type = {
     {QStringLiteral("favourite"), Notification::Type::Favorite},
     {QStringLiteral("follow"), Notification::Type::Follow},
@@ -112,6 +131,7 @@ static QMap<QString, Notification::Type> str_to_not_type = {
     {QStringLiteral("admin.report"), Notification::Type::AdminReport},
     {QStringLiteral("severed_relationships"), Notification::Type::SeveredRelationships},
     {QStringLiteral("moderation_warning"), Notification::Type::ModerationWarning},
+    {QStringLiteral("annual_report"), Notification::Type::AnnualReport},
 };
 
 Notification::Notification(AbstractAccount *account, const QJsonObject &obj, QObject *parent)
@@ -124,7 +144,11 @@ Notification::Notification(AbstractAccount *account, const QJsonObject &obj, QOb
 
     m_post = createPost(m_account, status, parent);
     m_identity = m_account->identityLookup(accountId, accountObj);
-    m_type = str_to_not_type[type];
+    if (str_to_not_type.contains(type)) {
+        m_type = str_to_not_type[type];
+    } else {
+        qCWarning(TOKODON_LOG) << "Unknown notification type:" << type;
+    }
     m_id = obj["id"_L1].toString().toInt();
 
     if (m_type == ModerationWarning) {
@@ -134,6 +158,8 @@ Notification::Notification(AbstractAccount *account, const QJsonObject &obj, QOb
     } else if (m_type == AdminReport) {
         m_report = new ReportInfo();
         m_report->fromSourceData(obj["event"_L1].toObject());
+    } else if (m_type == AnnualReport) {
+        m_annualReportEvent = AnnualReportEvent(obj["annual_report"_L1].toObject());
     }
 }
 
@@ -167,6 +193,11 @@ std::optional<RelationshipSeveranceEvent> Notification::relationshipSeveranceEve
     return m_relationshipSeveranceEvent;
 }
 
+std::optional<AnnualReportEvent> Notification::annualReportEvent() const
+{
+    return m_annualReportEvent;
+}
+
 std::optional<AccountWarning> Notification::accountWarning() const
 {
     return m_accountWarning;
