@@ -39,7 +39,8 @@ class RelationshipSeveranceEvent
     Q_PROPERTY(Type type READ type CONSTANT)
     Q_PROPERTY(bool purged READ purged CONSTANT)
     Q_PROPERTY(QString targetName READ targetName CONSTANT)
-    Q_PROPERTY(int relationshipsCount READ relationshipsCount CONSTANT)
+    Q_PROPERTY(int followersCount READ followersCount CONSTANT)
+    Q_PROPERTY(int followingCount READ followingCount CONSTANT)
 
 public:
     enum Type { DomainBlock, UserDomainBlock, AccountSuspension };
@@ -51,7 +52,8 @@ public:
     Type type() const;
     bool purged() const;
     QString targetName() const;
-    int relationshipsCount() const;
+    int followersCount() const;
+    int followingCount() const;
     QDateTime createdAt() const;
 
 private:
@@ -64,15 +66,48 @@ private:
     QDateTime m_createdAt;
 };
 
+class AnnualReportEvent
+{
+    Q_GADGET
+    QML_VALUE_TYPE(annualReportEvent)
+    Q_PROPERTY(QString year READ year CONSTANT)
+
+public:
+    AnnualReportEvent();
+    explicit AnnualReportEvent(const QJsonObject &source);
+    QString year() const;
+
+private:
+    QString m_year;
+};
+
 class Notification
 {
     Q_GADGET
+    QML_ELEMENT
+    QML_NAMED_ELEMENT(notification)
+    QML_UNCREATABLE("Only for enums")
 
 public:
     Notification() = default;
     explicit Notification(AbstractAccount *account, const QJsonObject &obj, QObject *parent = nullptr);
 
-    enum Type { Mention, Follow, Repeat, Favorite, Poll, FollowRequest, Update, Status, AdminSignUp, AdminReport, SeveredRelationships, ModerationWarning };
+    enum Type {
+        Unknown,
+        Mention,
+        Follow,
+        Repeat,
+        Favorite,
+        Poll,
+        FollowRequest,
+        Update,
+        Status,
+        AdminSignUp,
+        AdminReport,
+        SeveredRelationships,
+        ModerationWarning,
+        AnnualReport,
+    };
     Q_ENUM(Type);
 
     [[nodiscard]] int id() const;
@@ -82,6 +117,7 @@ public:
     [[nodiscard]] ReportInfo *report() const;
     [[nodiscard]] std::optional<RelationshipSeveranceEvent> relationshipSeveranceEvent() const;
     [[nodiscard]] std::optional<AccountWarning> accountWarning() const;
+    [[nodiscard]] std::optional<AnnualReportEvent> annualReportEvent() const;
     [[nodiscard]] std::shared_ptr<Identity> identity() const;
 
 private:
@@ -92,7 +128,8 @@ private:
     ReportInfo *m_report = nullptr;
     std::optional<RelationshipSeveranceEvent> m_relationshipSeveranceEvent;
     std::optional<AccountWarning> m_accountWarning;
-    Type m_type = Type::Favorite;
+    std::optional<AnnualReportEvent> m_annualReportEvent;
+    Type m_type = Type::Unknown;
     std::shared_ptr<Identity> m_identity;
 
     Post *createPost(AbstractAccount *account, const QJsonObject &obj, QObject *parent);
