@@ -4,7 +4,11 @@
 
 #include "timeline/threadmodel.h"
 
+#include "networkcontroller.h"
+
 #include <KLocalizedString>
+#include <QJsonDocument>
+#include <QNetworkReply>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -87,11 +91,11 @@ void ThreadModel::fillTimeline(const QString &fromId, bool backwards)
     auto thread = std::make_shared<QList<Post *>>();
 
     auto handleError = [this](QNetworkReply *reply) {
-        Q_UNUSED(reply);
         setLoading(false);
+        Q_EMIT NetworkController::instance().networkErrorOccurred(reply->errorString());
     };
 
-    auto onFetchContext = [=](QNetworkReply *reply) {
+    auto onFetchContext = [this, thread](QNetworkReply *reply) {
         const auto data = reply->readAll();
         const auto doc = QJsonDocument::fromJson(data);
         const auto obj = doc.object();
@@ -101,7 +105,7 @@ void ThreadModel::fillTimeline(const QString &fromId, bool backwards)
         }
 
         auto ancestors = obj["ancestors"_L1].toArray().toVariantList();
-        std::reverse(ancestors.begin(), ancestors.end());
+        std::ranges::reverse(ancestors);
 
         const auto descendents = obj["descendants"_L1].toArray();
 
@@ -135,7 +139,7 @@ void ThreadModel::fillTimeline(const QString &fromId, bool backwards)
         Q_EMIT nameChanged(); // update title
     };
 
-    auto onFetchStatus = [=](QNetworkReply *reply) {
+    auto onFetchStatus = [this, thread, contextUrl, onFetchContext, handleError](QNetworkReply *reply) {
         const auto data = reply->readAll();
         const auto doc = QJsonDocument::fromJson(data);
         const auto obj = doc.object();
@@ -190,4 +194,4 @@ bool ThreadModel::hasHiddenReplies() const
     return m_hasHiddenReplies;
 }
 
-#include "moc_threadmodel.cpp"
\ No newline at end of file
+#include "moc_threadmodel.cpp"
